# archimedean

Sends email whenever there is new homework on Archie website. Can download all files from any class in CineMath. Can download any resource posted on Archie. 
Still in testing phase.

## Installation

    Open the terminal
    Run 'pip install archimedean' to install

## Usage

    First run 'archimedean login' to save your credentials

    Commands:
    'archimedean login' logs you into Archie
    'archimedean homework' prints current homework and due dates to the command line
    'archimedean cinemath' downloads all lessons from a class in CineMath